.TH EVT2SAC 1  "07 August 1991"
.SH NAME
evt2sac \- convert seismic data on CD_ROM to SAC format
.SH SYNOPSIS
.B evt2sac
[ 
.I profile 
]
.SH DESCRIPTION
.B evt2sac
extracts seismic data from CD-ROMs distributed by the National Earthquake
Information Center (NEIC) of 
the United States Geological Survey (USGS) and converts it
to a form compatible with the Lawrence Livermore National Laboratory
Seismic Analysis Code (SAC).
The amplitude of the traces is left in "counts."
The station's instrument response is provided in an auxiliary file for
converting the counts to a physical quantity.

.I profile
is the name of a file containing information defining which event to
use and other information for personalizing the request.  See the
.B FILES
section for information on the profile.

If no
.I profile
is provided,
.B evt2sac
looks for a file named evt2sac.pro.

The user can specify the time of the event of interest and also specify
range and lag time to extract only records of interest.  In addition, 
it is possible to specify that the program extract data around the
arrival time of a phase.  For example, one could specify that the 
data should extend from one minute before the arrival of the P wave and run
until five minutes after the arrival of the S wave.  
The phases supported are P, S, pP, sS, PP, SS and surface waves.  When
specifying surface waves, the user can provide a surface wave group velocity
window.

It is possible to mark the arrivals of phases of interest so that they 
appear on a SAC plot.
.SH OPTIONS
None.
.ne 20
.SH FILES
If a profile is not specified when 
.B evt2sac
is invoked, a file called evt2sac.pro is used for the profile.

An example of a profile is:

.ne 14
.nf
---------------------------------------------
# This profile is for Taiwan event of May 20, 1986
#
year:                   1986
month:                  5
day:                    20
path:                   /mnt
minimum range:          10
maximum range:          30
minimum minutes:        3
maximum minutes:        60
---------------------------------------------
.fi

.ne 4
This profile will cause evt2sac to use the CD-ROM event file with name
"8614000.evt" (The Julian day of May 20 is 140) and extract records from
stations greater than 10 degrees from the event and no more than 30 degrees.
Also, only records, or portions thereof, between 3 minutes and 60 minutes
(after the event time) will be used.

The program runs through all the stations and produces files in the form:

.ne 10
.I prefix,sta,'.',period
[
.I,filenumber
]
.I ,direction,suffix

where:
.nf
        prefix:         user-specified 
        sta:            station name
        period:         's' (short), 'l' (long), or
                        'i' (intermediate)
        filenumber:     '00', '01', ...  If filenumber is '00',
                        it is omitted
        direction:      n (north), e (east), z (vertical)
        suffix:         user-specifed
.fi

.ne 6
For example, the short period, vertical trace from CHTO will have the
following file name if no prefix or suffix are specified:

.I chto.sz

If more than one short period record is created due to breaks in the data,
one could have the files:

.I chto.sz
.br
.I chto.01.sz
.br
.I chto.02.sz
.br
.I ....


.ne 10
There are two other files of interest generated: 

.I prefix.hdr
.br
.I prefix.dat

where 
.I prefix 
is the same as the prefix of the *.evt file.  The 
.I prefix.hdr
file is a copy of the header of the *.evt file and *.dat contains information
on each station such as the instrument response.


.ne 30
.B PROFILE COMMANDS

The allowed commands, and their defaults, which can be used in the profile are:

.nf
COMMAND                 DEFAULT         COMMENT
===================     =============   =================================
#whatever				Comment
PATH:                                   Set to path of CD-ROM reader
YEAR:                   1980            Year of event
MONTH:                  1               Month of event
DAY:                    1               Day of event
MAXIMUM RANGE:          180             Maximum range in degrees of arc
MINIMUM RANGE:          0               Minimum range in degrees of arc
MAXIMUM MINUTES:        360             Maximum time in minutes
MINIMUM MINUTES:        0               Minimum time in minutes
MINUTES BEFORE:         0               Time, in minutes, trace is to begin
                                        before the arrival of the phase 
                                        specified in the INITIAL PHASE command.
MINUTES AFTER:          0               Time, in minutes, trace is to end
                                        after arrival of the phase specified
                                        in the FINAL PHASE command.
INITIAL PHASE:                          The allowed phases are 'P', 'S', 'pP',
                                        'sS', 'PP', 'SS' and 'surface'.  
                                        (You do not put the
                                        quotation marks in the file.)
FINAL PHASE:                            Same as INITIAL PHASE.
SURFACE WAVE VELOCITY 1:  4.2           Surface wave velocity to define beginning
                                        of window in km/sec.
SURFACE WAVE VELOCITY 2:  4.2           Surface wave velocity  to define end
                                        of window in km/sec.
SAC FILE NAME PREFIX:                   Add this to beginning of SAC file name
SAC FILE NAME SUFFIX:                   Append this to the end of the SAC file name
EVENT NUMBER:           0               If you know which event in the specified
                                        *.evt file, you can avoid the interactive
                                        question concerning which event with 
                                        which you wish to work.  If EVENT NUMBER
                                        is not specified or is set to zero, the
                                        program will prompt you for the event
                                        number.
MARK PHASE:                             Mark a given arrival based on the
                                        J-B travel time curves.  The same
                                        phases are allowed as with the initial
                                        and final phases.  If "surface" is
                                        specified, the SURFACE WAVE VELOCITY 1
                                        is used to mark the trace.
PHASE FILE EXTENSION:			The default extension is ".jb" since 
					the travel times are based on the Jeffrey-
					Bullen tables.  You can create your own
					travel time curves and give them your
					own extension.
PHASE FILE EXTENSION:			Location of travel time curves.  The
					default is the current directory.
SET KZTIME TO START OF TRACE            The default is to set KZTIME to the
                                        time of the event, set 'O' to 0, and
					set IZTYPE to IO (Event origin time).
                                        If "SET KZTIME TO START OF TRACE"
                                        is specified, the KZTIME is set to the
                                        time of the beginning of the trace,
                                        'O' set to a negative number equal to
                                        the time before the trace that the event
                                        occurred, and IZTYPE is set to IB (Begin
					time).
                                        
.fi
NOTE: When determining which records to use and which portions of records to use,
.B ALL
conditions must be met.  That is, if the phases are specified and
they are outside the window specified by the range or the time limits,
no traces will be extracted.

When a command takes a parameter, the command ends with a colon.
There must be at least one space between the colon and the first character
of the parameter.

.ne 5
.B EXAMPLES:

Following is an example of a profile which specifies that we only want traces
from 30 seconds before the arrival of the P wave until 3 minutes after
the arrival of the S wave.

.ne 14
.nf
---------------------------------------------
year:                   1986
month:                  5
day:                    20
path:                   /mnt
minimum range:          10
maximum range:          30
minimum minutes:        3
maximum minutes:        60
initial phase:          P
minutes before:         0.5
final phase:            S
minutes after:          3       
---------------------------------------------
.fi

.ne 23
Following is an example of a profile which specifies that we only want traces
from 30 seconds before the arrival of a 4.5 km/sec surface wave until 2 minues
after the arrival of a 4.0 km/sec surface wave.


.nf
---------------------------------------------
year:                      1986
month:                     5
day:                       20
path:                      /mnt
minimum range:             10
maximum range:             30
minimum minutes:           3
maximum minutes:           60
initial phase:             surface
minutes before:            0.5
surface wave velocity 1:   4.5
final phase:               surface
minutes after:             2
surface wave velocity 2:   4.0   
---------------------------------------------
.fi

.ne 6
.B SPECIFYING LOCATION OF TRAVEL TIME CURVES

If the travel time curves (*.jb) are not in the current directory, you
can specify the directory with the environment variable EVT2SAC.  That is,

setenv EVT2SAC /seis/evt2sac

.ne 8
.B CHANGE PARAMETERS AT RUN TIME

When you invoke the program, you are shown all of the parameters as
set by the profile and given a chance to change any of them.  Each parameter
or group of parameters has a line number.  To change a parameter, enter
the line number.  The program then lets you change the parameter.
If you have made any changes, you will be given the option of saving
the profile either under the old name or a new name.  When you save a
profile, only the parameters are saved.  Comments are lost.

.ne 10
IF YOU DO NOT HAVE A CD-ROM READER ON YOUR SUN

If you do not have a CD-ROM reader and are bringing the *.evt files in
from another system such as an IBM PC, you can still use this program.
However, you must put the *.evt file(s) in a sub-directory appropriate
to the date of the event.  For example, say you are interested in an
event on January 13, 1985.  You would fetch the file 8501300.evt from
the "1985\JAN" sub-directory on the IBM, transmit it to the SUN as a binary file, and
place it in the sub-directory "1985/jan" off of your current working
directory.  In the profile do not specify a path.


Send comments, bug reports, etc., to the author:

.ce 4
Alan L. Jones
SUNY Geology Department
Binghamton, NY 13901
jones@sunquakes.geol.binghamton.edu

.ne 7
.SH CAVEATS

This version allows the user to access all data included in CD-ROM volumes
1-6.  It will work on later volumes unless data with new format(s) are
added.  Even in those cases, data with older formats can still be extracted.
The program is written in modules, such that new formats can be 
incorporated easily.



.SH DISTRIBUTION

The evt2sac package is distributed over the network as a TAR file.  When
unpacked

.B tar -xvf evt2sac.TAR

you will have source code in a sub-directory called c2s.

.ne 10
.SH COMPILING FOR USE ON YOUR SYSTEM

The compiled programs and object files are not distributed with evt2sac
since they depend on the workstation architecture.
To compile and link evt2sac, edit the file 
.B makefile 
according to the instructions in that file.  Then:

.B make

.ne 20
.SH OTHER PROGRAMS

The program 
.B makeindex
will create an index of the CD-ROM which is in
the drive and the program 
.B viewindex
allows you to view the index to
pick out an event.  The form of the index is similar to that provided
in hard copy form with each CD-ROM.  By having the indices in machine-
readable form, one can quickly scan the events to pick out those of
interest.  

These programs are not distributed in evt2sac.TAR but will be sent 
upon request in a file
.B index.TAR. 
In addition to the Sun programs
for creating and viewing CD-ROM indices, there are equivalent
IBM PC programs to do the same.


.ne 10
.SH ACKNOWLEDGMENTS

The program is based on a program written by
Science Horizons and enhanced by Jeff Barker and Francis Wu of SUNY 
Binghamton.  The original program was written to extract data out of a CD-ROM
volume 1.  The enhancement extended its applicability to later volumes
and made it more friendly.  But it did not work for RSTN or later data
due to the various data formats used.  Some of the JB tables
were provided by Anthony Lomax of UC Berkeley.

The modifications to the original Science Horizons program were sponsored
by the Incorporated Research Institutions for Seismology (IRIS) of
Arlington, Virginia.  The contracting officer is Tim Ahern.

.SH CHANGES

91.03.11: The PP.jb and SS.jb tables have been fixed.  Previously they were
	not correct except for near-surface events.  Depth (EVDP) added to SAC header.
1999.04.13: With help of Jeff Barker, changed makefile to allow it to
	work under Solaris.  Had to fetch the mach and hdr SAC header
	files from SAC and put in a inc sub-directory under this one.
