/* ndt_subs.c */
#include <math.h>
#include "ndt_logs.h"

extern int cdver;	/* Defined in evt2sac.c.  CD-ROM version */

/*
**  extract info from first 2000 byte block of CD-ROM files 
**  ( note that this block does not normally appear on either
**   a network day tape or an event tape. It was placed in these
**   files to aid in unravelling them in the absence of tape marks ).
*/
crack_file_header(bp,hp)
char bp[25][81];
struct file_header *hp;
{
        int i;

        sscanf(bp[0],"%s%d%d%d%d%d%d%d%*s%d",
                hp->unknown1,
                &hp->unknown2,
                &hp->nsta,
                &hp->year,
                &hp->unknown3,
                &hp->unknown4,
                &hp->unknown5,
                &hp->nblock,
                &hp->version );
        /*****************************************
	** 6/13/90: Add scanning for data in second column 
	** 	    and handle up to 48 stations.
	******************************************/
        for( i = 0 ; i<24 ; i++ ) {
                sscanf(bp[i+1],"%d%d%d%d%d%d%d%d",
                &hp->sblock[i],
                &hp->nspblk[i],
                &hp->nlpblk[i],
                &hp->nipblk[i],
		&hp->sblock[i+24],
                &hp->nspblk[i+24],
                &hp->nlpblk[i+24],
                &hp->nipblk[i+24]);
	} 
	/*****
	for(i=0;i<hp->nsta;i++) {
		printf("%2d: %4d %3d %3d %3d\n",
		i+1,
		hp->sblock[i],
                hp->nspblk[i],
                hp->nlpblk[i],
                hp->nipblk[i]);
	}
	i = getchar();
	*****/
}

/*
**  Extract info from tape log (this is normally the first block
**    of a network day tape or event tape ).
*/
crack_tape_log(bp,lp,blk)
char bp[25][81];
struct tape_log *lp;
int blk;	/* Which block we're on */
{
        int i;
	int n;
	int staid1,staid2,fmtid1,fmtid2,tfile1,tfile2;
	char sta1[10],sta2[10],instyp1[10],instyp2[10];

        sscanf(bp[2],"%*s %d %*s %d",&lp->doy,&lp->year);
	/***
        printf("Day of year: %d , Year: %d\n",lp->doy,lp->year);
	***/

        sscanf(bp[5],"%*s %*s %*s %d",&lp->nsta);

	/***
	printf("%s\n",bp[5]);
	printf("nsta: %d\n",lp->nsta);
	***/
	blk = blk*36;
        for( i = 0; i < 18 ; i++ ){
                n =sscanf(bp[i+7],"%d%s%s%d%d%d%s%s%d%d",
		&staid1,sta1,instyp1,&fmtid1,&tfile1,
		&staid2,sta2,instyp2,&fmtid2,&tfile2);
		/*printf("n: %d %s\n",n,bp[i+7]);*/
		if(n>0) {
			lp->staid[blk+i] = staid1;
			strcpy(lp->sta[blk+i],sta1);
			strcpy(lp->instyp[blk+i],instyp1);
			lp->fmtid[blk+i] = fmtid1;
			lp->tfile[blk+i] = tfile1;
			if(n>5) {
				lp->staid[blk+i+18] = staid2;
				strcpy(lp->sta[blk+i+18],sta2);
				strcpy(lp->instyp[blk+i+18],instyp2);
				lp->fmtid[blk+i+18] = fmtid2;
				lp->tfile[blk+i+18] = tfile2;
			}
		}
        }
	/***
        for( i = 0 ; i < lp->nsta; i++ ){
                printf("%2d: %d %s %s %d %d\n",
		i+1,
                lp->staid[i],
                lp->sta[i],
                lp->instyp[i],
                lp->fmtid[i],
                lp->tfile[i]);
        }	
	getchar();
	***/
}

/*
**  This event log probably only appears on event tapes. It is not
**  documented in the open file report on network day tapes.
*/
crack_event_log(bp,lp)
char bp[25][81];
struct event_log *lp;
{
        register int i;
        int nis;
	struct date_time *pdt;

        sscanf(bp[2],"%d%d",&lp->doy,&lp->year);

        for( i = 0 ; i < 25 ; i++ ){
		pdt = &lp->edt[i];
                nis = sscanf(bp[i+7],"%d%d%d%d:%d:%f%f%f%f%f%f",
                        &pdt->year,
                        &pdt->month,
                        &pdt->day,
                        &pdt->hour,
                        &pdt->minute,
                        &pdt->second,
                        &lp->elat[i],
                        &lp->elon[i],
                        &lp->edepth[i],
                        &lp->emb[i],
                        &lp->ems[i]    );
                
                if( nis < 1 ) break;
		/*** 9/11/90: ALJ Replace call to csstim routine mdtodate ***/
		/*** with call to our julian routine ***/
		pdt->doy = julian(pdt->year,
					pdt->month,
					pdt->day);
                /* mdtodate(&lp->edt[i]); */
                pdt->date = pdt->year * 1000 + pdt->doy;
                htoe(pdt);
        }

        lp->nevent = i;
}

/*
**  Extract information from station log. This block introduces the
**  data for a given station.
*/
crack_station_log(bp,lp)
char bp[25][81];
struct station_log *lp;
{
        char latdir;
        char londir;

        sscanf(bp[0],"STATION LOG:%25.25s",lp->long_name);
        sscanf(bp[4],"%d%s%s%f%c%f%c%f",
                &lp->staid,
                 lp->sta,
                 lp->instyp,
                &lp->lat,
                &latdir,
                &lp->lon,
                &londir,
                &lp->elev   );
                if( latdir == 'S' ) lp->lat = -(lp->lat);
                if( londir == 'W' ) lp->lon = -(lp->lon);
}

/*
**  Extract info from first data log block. This log has the calibration
**  information in it for the channels of data which follow.
*/
crack_data_log1(bp,lp)
char bp[25][81];
struct data_log1 *lp;
{
        double calib;
        double calfreq;
        int i,nis;
        char str[21];
        double atof();

        for( i = 0 ; i < 18 ; i++ ){
                        strncpy(str,&bp[i+8][0],8); str[8] = '\0';
                        lp->chanid[i] = atoi(str);
                        if( !(lp->chanid[i]) ) break;
                        strncpy(str,&bp[i+8][8],11); str[11] = '\0';
                        lp->year[i] = atoi(str);
                        strncpy(str,&bp[i+8][19],4); str[4] = '\0';
                        lp->doy[i] = atoi(str);
                        strncpy(str,&bp[i+8][23],5); str[5] = '\0';
                        lp->tod[i] = atoi(str);
                        strncpy(str,&bp[i+8][28],14); str[14] = '\0';
                        lp->amp[i] = atof(str);
                        strncpy(str,&bp[i+8][42],20); str[20] = '\0';
                        calib = atof(str);
                        strncpy(str,&bp[i+8][62],17); str[17] = '\0';
                        calfreq = atof(str);
                        lp->calib[i] = 1000. / calib;
                        if( calfreq < .001 ) lp->calper[i] = -1.0;
                        else lp->calper[i] = 1.0 / calfreq;
        }
        lp->ncals = i;
}

/*
**  Extract the BCD info from the first 20 bytes of each data block.
*/
crack_data_header(bp,hp)
unsigned char *bp;
struct data_header *hp;
{
        int srexp;
        int srat;
        int second;
        int msec;

        hp->staid      =  100 * (*bp >> 4) + 10 * (*bp++ & 0x0f);
        hp->staid     +=  (*bp >> 4);
        hp->dt.year    =  10  * (*bp++ & 0x0f);
        hp->dt.year   +=  (*bp >> 4);
        hp->dt.year   +=  1900;
        hp->dt.doy     =  100 * (*bp++ & 0x0f);
        hp->dt.doy    +=  10 * (*bp >> 4) + (*bp++ & 0x0f);
        hp->dt.date    =  hp->dt.year * 1000 + hp->dt.doy;
        hp->dt.hour    =  10  * (*bp >> 4) + (*bp++ & 0x0f);
        hp->dt.minute  =  10  * (*bp >> 4) + (*bp++ & 0x0f);
        second         =  10  * (*bp >> 4) + (*bp++ & 0x0f);
        msec           =  100 * (*bp >> 4) + 10 * (*bp++ & 0x0f);
        msec          +=  (*bp >> 4);
        hp->dt.second  =  (float)second + .001 * msec;
        hp->fmtid      =  (*bp++ & 0x0f);
        hp->sbits      =  *bp++;
        hp->nchan      =  10  * (*bp >> 4) + (*bp++ & 0x0f);
        srexp          =  (*bp >> 4);
        srat           =  10  * (*bp++ & 0x0f);
        srat          +=  (*bp >> 4);
        hp->smprat     =  (float)srat * pow(10.0,(float)(5 - srexp));
        hp->nsamp      =  100 * (*bp++ & 0x0f);
        hp->nsamp     +=  10 * (*bp >> 4) + (*bp++ & 0x0f);
        htoe(&hp->dt);
}


/***********************************************************************************
**  The data format id found in the data block header determines the data format.
**  On June 12, 1990 the program supported only :
**
**  1: SRO/ASRO format (4/12 gain ranged)
**  2: DWSSN (straight 16 bit integer) format. 
**
**  6/12/90: Add formats:
**
**  3: RSTN (2 bits gain followed by 14 bits mantissa)
**  4: GRF  (12 bits of mantissa followed by 4 bits gain)
**  5: GEOSCOPE (4 bits gain followed by 12 bits mantissa)
**
**  We call routines to reformat these to 32
**  bit integer form for storage. Note that the samples still represent
**  raw digital counts and must be multiplied by calib to get nanometers.
**************************************************************************************/
reformat_data(ip,op,ns,flag)
int *op;
short *ip;
int ns;
int flag;
{
        switch( flag ){
                case 1:         /* SRO - ASRO 4/12 gain ranged */
                        sro(ip+10, op, ns );
                        return(ns);
                case 2:         /* DWWSSN 16 bits integer */
                        dwwssn(ip+10, op, ns );
                        return(ns);
                case 3:         /* RSTN 2/14 gain ranged */
                        rstn(ip+10, op, ns );
                        return(ns);
                case 4:         /* GRF 12/4 gain ranged */
                        grf(ip+10, op, ns );
                        return(ns);
                case 5:         /* GEOSCOPE 4/12 gain ranged */
                        geoscope(ip+10, op, ns );
                        return(ns);
                default:
                        return(-1);
        }
}
                        
/************************************************************
**   Degain SRO and ASRO data to 32 bit integer format.
**   This routine assumes the data are 4/12 gain ranged and that
**   the mantissa is a 12 bit 2s compliment integer. The degained
**   value is gotten by: v = m * 2 ^ (10 - g).
*************************************************************/
sro( in, out, num )
short *in;
int *out;
int num;
{
        register int gain;
        register int value;
        register int count = num;

        while( count-- ){
                gain = (*in >> 12) & 0x0f;      /* MS 4 bits are gain code */
                value = *in << 20;              /* push LS 12 bits to top */
                value = value >> ( 10 + gain);  /* now adjust for gain code */
                *out++ = value;
                in++;
        }
}

/*
**   Short integer to long integer conversion for DWWSSN data.
*/
dwwssn(in,out,num)
short *in;
long *out;
{
        register int count = num;

        while( count-- ) *out++ = *in++;
}
/************************************************************
**   Degain RSTN data to 32 bit integer format.
**   This routine assumes the data are 2/14 gain ranged and that
**   the mantissa is a 14 bit unsigned integer with an offset of 8191. The degained
**   value is gotten by: v = (m - 8191) * (1, 4, 16, 128)[gain]
**   or: v = (m - 8191) * 2 ^ (0, 2, 4, 8)[gain]
*************************************************************/
rstn( in, out, num )
short *in;
int *out;
int num;
{
	static int rstn_pow[] = {0, 2, 4, 128};
        register int gain;
        register int value;
        register int count = num;

        while( count-- ){
                gain = (*in >> 14) & 0x03;      /* MS 2 bits are gain code */
                value = *in & 0x03fff;          /* Get mantissa */
                value = (value - 8191) << rstn_pow[gain];  /* now adjust for gain code */
                *out++ = value;
                in++;
        }
}
/************************************************************
**   Degain GRF data to 32 bit integer format.
**   This routine assumes the data are 12/4 gain ranged  (mantissa follwed by gain) and that
**   the mantissa is a 12 bit 2s compliment integer. The degained
**   value is gotten by: v = m * 2 ^ (12 - g).
*************************************************************/
grf( in, out, num )
short *in;
int *out;
int num;
{
        register int gain;
        register int value;
        register int count = num;

        while( count-- ){
                gain = *in & 0x0f;     	        /* LS 4 bits are gain code */
		value = *in & 0xfff0;		/* Get mantissa */
		value <<= 16;			/* Move to top (shift of 20 all together) */
                value >>= 8 + gain;		/* now adjust for gain code */
                *out++ = value;
                in++;
        }
}
/************************************************************
**   Degain GEOSCOPE data to 32 bit integer format.
**   This routine assumes the data are 4/12 gain ranged and that
**   the mantissa is a 12 bit unsigned integer. The degained
**   value is gotten by: v = (m - 2048) * 2 ^ (- g).
**   (This looks fishy since, if gain is large, significant bits will roll off end.)
**   (I'll fix it so that we don't lose significance but the value will probably
**   be too large.)
*************************************************************/
geoscope( in, out, num )
short *in;
int *out;
int num;
{
        register int gain;
        register int value;
        register int count = num;

        while( count-- ){
                gain = (*in >> 12) & 0x0f;      /* MS 4 bits are gain code */
                value = *in &  0xfff0;          /* Get mantissa */
		value <<= 20;			/* Put all the way to left */
                value >>= gain;			/* now adjust for gain code */
                *out++ = value;
                in++;
        }
}


/* demultiplex 3 component data blocks */
demux(dp,zp,np,ep,ns)
int *dp,*zp,*np,*ep;
int ns;
{
        register int count = ns / 3;

        while( count-- ){
                *zp++   = *dp++;
                *np++   = *dp++;
                *ep++   = *dp++;
        }
}

int read_block(fd,bp)
int fd;
char *bp;
{
	int i;
        i = read(fd,bp,2000);
	if(i == 2000 )
       		 if(cdver==1) bwswap(bp,2000);
	return i;
}

/* byte and word swap blocks from VAX byte order to SUN byte order */
bwswap(bp,nc)
char *bp;
int nc;
{
        int i;
        int ns = nc / 2;
        int nw = nc / 4;
        char tmpc,*cp;
        short tmps,*sp;

        cp = bp;
        for( i = 0 ; i < ns ; i++ ){
                tmpc = *cp;
                *cp = *(cp+1);
                *(cp+1) = tmpc;
                cp += 2;
        }

        sp = (short *)bp;
        for( i = 0 ; i < nw ; i++ ){
                tmps = *sp;
                *sp = *(sp+1);
                *(sp+1) = tmps;
                sp += 2;
        }
}

/* split 2000 byte blocks into 80 character "card image" strings */
line_split(in,out)
char *in;
char out[25][81];
{
        register int i;

        for( i = 0 ; i < 25 ; i++ ){
                strncpy(out[i],in,80);
                out[i][81] = '\0';
                in += 80;
        }
}
